@@ -191,13 +191,13 @@ sub access_data_cache
 	#
 	# Validate parameters
 	#
-	if (my @invalids = grep(!/^(memory_cache|cache_file|tie_class)$/,keys(%options))) {
+	if (my @invalids = grep(!/^(action|memory_cache|cache_file|tie_class)$/,keys(%options))) {
 	    die "cache: invalid parameter '$invalids[0]' for action '$action'\n";
 	}
 	
 	my %in;
 	tie (%in, $tieClass, $cacheFile, O_RDONLY, 0);
-	my @keys = keys(%in);
+	my @keys = map(substr($_,0,-9),grep(/\.contents$/,keys(%in)));
 	untie (%in);
 	return @keys;
 	
